@@ -541,6 +541,10 @@ mod build {
         .whitelist_function("shm_create_chunk")
         .whitelist_function("shm_set_data_state")
         .whitelist_function("shm_get_data_state")
+        .whitelist_function("dds_is_loan_available")
+        .whitelist_function("dds_is_shared_memory_available")
+        .whitelist_function("dds_loan_shared_memory_buffer")
+        .whitelist_function("dds_loan_sample")
         .whitelist_function("_dummy")
         .whitelist_type("dds_stream_opcode")
         .whitelist_type("dds_stream_typecode")
